/*
 * Copyright (c) 2004-2005 by John Schmerge.
 * All rights reserved.
 *
 * $Id: job.h,v 1.5 2005/03/27 01:20:31 john Exp $
 */

#ifndef JOB_H
#define JOB_H 1

/* ********************************************************************
 */
typedef unsigned long U32;
typedef unsigned short U16;
typedef unsigned char U8;

/* ********************************************************************
 */
struct JobTime
{
	U32 minute[2];
	U32 hour;
	U32 dayOfMonth;
	U16 month;
	U8  dayOfWeek;
};

/* ********************************************************************
 */
struct Job
{
	struct Job * next;

	struct JobTime jobTime;
	char * command;
};

/* ********************************************************************
 */
struct JobQueue
{
	struct JobQueue * next;
	struct TabOptions * options;
	struct Job * job;
};

/* ********************************************************************
 */
void destroyJobList(struct Job ** list);

/* ********************************************************************
 */
int jobTimeMatch(struct JobTime * jt, time_t * time);

/* ********************************************************************
 */
typedef void (*SetJobTimeFunc)(struct JobTime *, int);

/* ********************************************************************
 * These functions are actual functions instead of macros because they
 * are passed as function pointers to one of the parsing routines
 */
void setJobTimeMinute(struct JobTime * jt, int minute);
void setJobTimeHour(struct JobTime * jt, int hour);
void setJobTimeDom(struct JobTime * jt, int dom);
void setJobTimeMonth(struct JobTime * jt, int month);
void setJobTimeDow(struct JobTime * jt, int dow);

/* ********************************************************************
 */
void queueJob(struct JobQueue ** jq, struct TabOptions * opts,
              struct Job * job);

/* ********************************************************************
 */
void runJobQueue(struct JobQueue ** jq);

#endif /* JOB_H */

/* ********************************************************************
 * $Log: job.h,v $
 * Revision 1.5  2005/03/27 01:20:31  john
 * updated copyright
 *
 * Revision 1.4  2003/02/11 09:16:27  john
 * size-reducing changes; also removed the job input spec
 *
 * Revision 1.3  2003/02/09 20:46:38  john
 * added job output support; everything but mailing of job output works
 * correctly
 *
 * Revision 1.2  2003/01/22 07:50:19  john
 * removed typedefs
 *
 * Revision 1.1.1.1  2002/10/06 06:47:18  john
 * initial import of sources
 *
 */
